@@ -33,8 +33,7 @@ import os
 
 from jupyterhub.auth import LocalAuthenticator
 from tornado.httpclient import HTTPRequest
-from traitlets import default
-from traitlets import Unicode
+from traitlets import Unicode, default
 
 from .oauth2 import OAuthenticator
 
@@ -53,6 +52,7 @@ class Auth0OAuthenticator(OAuthenticator):
                 "Please specify $AUTH0_SUBDOMAIN env or %s.auth0_subdomain config"
                 % self.__class__.__name__
             )
+        return subdomain
 
     username_key = Unicode(
         os.environ.get("OAUTH2_USERNAME_KEY", "email"),
