@@ -7,25 +7,16 @@ import base64
 import json
 import os
 import uuid
-from urllib.parse import quote
-from urllib.parse import urlparse
-from urllib.parse import urlunparse
+from urllib.parse import quote, urlparse, urlunparse
 
 from jupyterhub.auth import Authenticator
-from jupyterhub.handlers import BaseHandler
-from jupyterhub.handlers import LogoutHandler
+from jupyterhub.handlers import BaseHandler, LogoutHandler
 from jupyterhub.utils import url_path_join
 from tornado import web
 from tornado.auth import OAuth2Mixin
-from tornado.httpclient import AsyncHTTPClient
-from tornado.httpclient import HTTPClientError
+from tornado.httpclient import AsyncHTTPClient, HTTPClientError
 from tornado.log import app_log
-from traitlets import Any
-from traitlets import Bool
-from traitlets import default
-from traitlets import Dict
-from traitlets import List
-from traitlets import Unicode
+from traitlets import Any, Bool, Dict, List, Unicode, default
 
 
 def guess_callback_uri(protocol, host, hub_server_url):
@@ -230,8 +221,8 @@ class OAuthCallbackHandler(BaseHandler):
         self.check_arguments()
         user = await self.login_user()
         if user is None:
-            # todo: custom error page?
-            raise web.HTTPError(403)
+            raise web.HTTPError(403, self.authenticator.custom_403_message)
+
         self.redirect(self.get_next_url(user))
 
 
@@ -292,6 +283,12 @@ class OAuthenticator(Authenticator):
     def _logout_redirect_url_default(self):
         return os.getenv("OAUTH_LOGOUT_REDIRECT_URL", "")
 
+    custom_403_message = Unicode(
+        "Sorry, you are not currently authorized to use this hub. Please contact the hub administrator.",
+        config=True,
+        help="""The message to be shown when user was not allowed""",
+    )
+
     scope = List(
         Unicode(),
         config=True,
@@ -437,21 +434,33 @@ class OAuthenticator(Authenticator):
     def _deprecated_oauth_trait(self, change):
         """observer for deprecated traits"""
         old_attr = change.name
-        new_attr, version = self._deprecated_oauth_aliases.get(old_attr)
+        try:
+            new_attr, version, same = self._deprecated_oauth_aliases.get(old_attr)
+        except ValueError:
+            # if `same` flag wasn't passed, we assume the new and old trait have the same type
+            new_attr, version = self._deprecated_oauth_aliases.get(old_attr)
+            same = True
+
         new_value = getattr(self, new_attr)
         if new_value != change.new:
             # only warn if different
             # protects backward-compatible config from warnings
             # if they set the same value under both names
-            self.log.warning(
-                "{cls}.{old} is deprecated in {cls} {version}, use {cls}.{new} instead".format(
-                    cls=self.__class__.__name__,
-                    old=old_attr,
-                    new=new_attr,
-                    version=version,
-                )
+            message = "{cls}.{old} is deprecated in {cls} {version}, use {cls}.{new} instead".format(
+                cls=self.__class__.__name__,
+                old=old_attr,
+                new=new_attr,
+                version=version,
             )
-            setattr(self, new_attr, change.new)
+
+            # set the value for the new attr only if they are the same type
+            # otherwise raise an error because unexpected things can happen
+            if same:
+                self.log.warning(message)
+                setattr(self, new_attr, change.new)
+            else:
+                self.log.error(message)
+                raise ValueError(message)
 
     def __init__(self, **kwargs):
         # observe deprecated config names in oauthenticator
