@@ -3,11 +3,9 @@ import json
 import logging
 import re
 from io import BytesIO
-from urllib.parse import parse_qs
-from urllib.parse import urlparse
+from urllib.parse import parse_qs, urlparse
 
-from pytest import fixture
-from pytest import mark
+from pytest import fixture, mark
 from tornado.httpclient import HTTPResponse
 from tornado.httputil import HTTPHeaders
 from traitlets.config import Config
