@@ -8,8 +8,7 @@ import requests_mock
 from pytest import fixture
 from tornado import web
 
-from ..mediawiki import AUTH_REQUEST_COOKIE_NAME
-from ..mediawiki import MWOAuthenticator
+from ..mediawiki import AUTH_REQUEST_COOKIE_NAME, MWOAuthenticator
 from .mocks import mock_handler
 
 MW_URL = 'https://meta.wikimedia.org/w/index.php'
@@ -20,7 +19,7 @@ def mediawiki():
     def post_token(request, context):
         authorization_header = request.headers['Authorization'].decode('utf8')
         request_nonce = re.search(r'oauth_nonce="(.*?)"', authorization_header).group(1)
-        return jwt.encode(
+        content = jwt.encode(
             {
                 'username': 'wash',
                 'aud': 'client_id',
@@ -29,7 +28,9 @@ def mediawiki():
                 'nonce': request_nonce,
             },
             'client_secret',
-        )
+        ).encode()
+
+        return content
 
     with requests_mock.Mocker() as mock:
         mock.post(
